==> kolibri-0.15.7.tar.gz: kolibri-0.15.7/AUTHORS.md <==
# Contributors

Kolibri is copyrighted by Learning Equality under the MIT License.

If you have contributed to Kolibri, feel free to add your name and Github account to this list:

| Name | Github user |
|------|-------------|
| Eli Dai | 66eli77 |
| Adam Stasiw | AdamStasiw |
| Akshay Mahajan | akshaymahajans |
| Alan Chen | alanchenz |
| Alexandros Metaxas | alexMet |
| Apurva Modi | apurva-modi |
| Eduard James Aban | arceduardvincent |
| Arky | arky |
| Aron Fyodor Asor | aronasorman |
| Ashmeet Lamba | ashmeet13 |
| Kapya | Aypak |
| Benjamin Bach | benjaoming |
| Blaine Jester | bjester |
| Boni Đukić | bonidjukic |
| Brian Kwon | br-kwon |
| Brandon Nguyen | bransgithub |
| John | BruvaJ |
| Chao-Wen Tan | chaowentan |
| Christian Memije | christianmemije |
| Cyril Pauya | cpauya |
| Chris Castle | crcastle |
| David Garg | davidgarg20 |
| David Hu | divad12 |
| Derek Lobo | dlobo |
| David Cañas | DXCanas |
| Dylan McCall | dylanmccall |
| Mingqi Zhu | EmanekaT |
| Gerardo Soto | GCodeON |
| Geoff Rich | geoffrey1218 |
| Hans Gamboa | HansGam |
| Devon Rueckner | indirectlylit |
| inflrscns | inflrscns |
| Ivan Savov | ivanistheone |
| Jamie Alexandre | jamalex |
| Jason Tame | JasonTame |
| Jordan Yoshihara | jayoshih |
| Jessica Aceret | jessicaaceret |
| Jonathan Boiser | jonboiser |
| José L. Redrejo Rodríguez | jredrejo |
| Jessica Aceret | jtamiace |
| Julián Duque | julianduque |
| Karla Avila | k2avila |
| Mrinal Kumar | kmrinal19 |
| Kevin Ollivier | kollivier |
| Paul Luna | luna215 |
| Lingyi Wang | lyw07 |
| Magali Boizot-Roche | magali-br |
| manuq | manuq |
| Marcella Maki | marcellamaki |
| Maureen Hernandez | MauHernandez |
| Michael Gallaspy | MCGallaspy |
| Leo Lin | mdctleo |
| Metodi Milev | metodimilevqa |
| Michael Gamlem III | mgamlem3 |
| Micah Fitch | micahscopes |
| Michaela Robosova | MisRob |
| Eduard James Aban | mrpau-eduard |
| Eugene Oliveros | mrpau-eugene |
| Julius legaspi | mrpau-julius |
| Richard Amodia | mrpau-richard |
| Nick Cannariato | nickcannariato |
| Jacob Pierce | nucleogenesis |
| Paul Bussé | paulbusse |
| Petar Cenov | pcenov |
| Radina Matic | radinamatic |
| Rafael Aguayo | ralphiee22 |
| Hyun Ahn | rationality6 |
| Rachel Kim | rayykim |
| Richard Tibbles | rtibbles |
| Sairina Merino Tsui | sairina |
| Shanavas M | shanavas786 |
| shivangtripathi | shivangtripathi |
| Udith Prabhu | udithprabhu |
| Vivek Agrawal | vkWeb |
| Whitney Zhu | whitzhu |
| Carol Willing | willingc |
| Yash Jipkate | YashJipkate |
| Yixuan Liu | yil039 |

==> kolibri-0.16.0.tar.gz: kolibri-0.16.0/AUTHORS.md <==
# Contributors

Kolibri is copyright Learning Equality and other contributors, and is released under the MIT License.

If you have contributed to Kolibri, feel free to add your name and Github account to this list:

| Name | Github user |
|--|-------------|
| Eli Dai | 66eli77 |
| Adam Stasiw | AdamStasiw |
| Akshay Mahajan | akshaymahajans |
| Alan Chen | alanchenz |
| Alexandros Metaxas | alexMet |
| Apurva Modi | apurva-modi |
| Eduard James Aban | arceduardvincent |
| Arky | arky |
| Aron Fyodor Asor | aronasorman |
| Ashmeet Lamba | ashmeet13 |
| Kapya | Aypak |
| Benjamin Bach | benjaoming |
| Blaine Jester | bjester |
| Boni Đukić | bonidjukic |
| Brian Kwon | br-kwon |
| Brandon Nguyen | bransgithub |
| John | BruvaJ |
| Chao-Wen Tan | chaowentan |
| Christian Memije | christianmemije |
| Connor Robertson | conconrob |
| Cyril Pauya | cpauya |
| Chris Castle | crcastle |
| David Garg | davidgarg20 |
| David Hu | divad12 |
| Derek Lobo | dlobo |
| David Cañas | DXCanas |
| Dylan McCall | dylanmccall |
| Mingqi Zhu | EmanekaT |
| Gerardo Soto | GCodeON |
| Geoff Rich | geoffrey1218 |
| Hans Gamboa | HansGam |
| Devon Rueckner | indirectlylit |
| - | inflrscns |
| Ivan Savov | ivanistheone |
| Jamie Alexandre | jamalex |
| Jason Tame | JasonTame |
| Jordan Yoshihara | jayoshih |
| Jessica Aceret | jessicaaceret |
| Jonathan Boiser | jonboiser |
| José L. Redrejo Rodríguez | jredrejo |
| Jessica Aceret | jtamiace |
| Julián Duque | julianduque |
| Karla Avila | k2avila |
| Maxime Brunet | maxbrunet |
| Mrinal Kumar | kmrinal19 |
| Kevin Ollivier | kollivier |
| Paul Luna | luna215 |
| Lingyi Wang | lyw07 |
| Magali Boizot-Roche | magali-br |
| - | manuq |
| Marcella Maki | marcellamaki |
| Maureen Hernandez | MauHernandez |
| Michael Gallaspy | MCGallaspy |
| Leo Lin | mdctleo |
| Metodi Milev | metodimilevqa |
| Michael Gamlem III | mgamlem3 |
| Micah Fitch | micahscopes |
| Michaela Robosova | MisRob |
| Eduard James Aban | mrpau-eduard |
| Eugene Oliveros | mrpau-eugene |
| Julius legaspi | mrpau-julius |
| Richard Amodia | mrpau-richard |
| Nick Cannariato | nickcannariato |
| Jacob Pierce | nucleogenesis |
| Paul Bussé | paulbusse |
| Petar Cenov | pcenov |
| Philip Withnall | pwithnall |
| Radina Matic | radinamatic |
| Rafael Aguayo | ralphiee22 |
| Hyun Ahn | rationality6 |
| Rachel Kim | rayykim |
| Richard Tibbles | rtibbles |
| Sairina Merino Tsui | sairina |
| Shanavas M | shanavas786 |
| - | shivangtripathi |
| Udith Prabhu | udithprabhu |
| Whitney Zhu | whitzhu |
| Carol Willing | willingc |
| Yash Jipkate | YashJipkate |
| Yixuan Liu | yil039 |
| Jaideep Sharma | camperjett |
| Allan Otodi | AllanOXDi |
| Liana Harris | LianaHarris360 |
| Rishi Kejriwal | Kej-r03 |
| Siddhanth Rathod | siddhanthrathod |
| Akila Induranga | akila-i |
| Sahajpreet Singh | photon0205 |
| Nishant Shrivastva | shrinishant  |
| Amelia Breault | thanksameeelian |
| Vikramaditya Singh | Ghat0tkach |
| Kris Katkus | katkuskris |
| Garvit Singhal | GarvitSinghal47 |
| Mazen Oweiss | moweiss |
